summaryrefslogtreecommitdiff
path: root/cli
diff options
context:
space:
mode:
authorRocky Madden <git@rockymadden.com>2012-10-31 13:21:59 -0600
committerRocky Madden <git@rockymadden.com>2012-10-31 13:21:59 -0600
commit7dd3e979871812c969de54c1e6b02de68b927619 (patch)
treed5ee29a07a33f29a59341e3b00e4bd5c70bd8ece /cli
parent24ca58dd608af4482ae2f0a324c2210b7fc55858 (diff)
downloadstringmetric-7dd3e979871812c969de54c1e6b02de68b927619.tar.gz
stringmetric-7dd3e979871812c969de54c1e6b02de68b927619.tar.bz2
stringmetric-7dd3e979871812c969de54c1e6b02de68b927619.zip
More sensible and consistent package structuring.
Diffstat (limited to 'cli')
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/Command.scala)4
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithm.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithm.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithm.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithm.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/hammingMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/levenshteinMetric.scala)5
-rwxr-xr-xcli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/command/package.scala)4
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithmSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithmSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithmSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithmSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/hammingMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetricSpec.scala)2
-rwxr-xr-xcli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/command/levenshteinMetricSpec.scala)2
28 files changed, 42 insertions, 57 deletions
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/Command.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala
index 77324b8..062fefe 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/Command.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala
@@ -1,6 +1,4 @@
-package org.hashtree.stringmetric.cli.command
-
-import org.hashtree.stringmetric.cli.OptionMap
+package org.hashtree.stringmetric.cli
/** Defines the traits and provides basic implementations of a command. Commands are always implemented as objects. */
trait Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithm.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala
index 50f2e8f..673812f 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithm.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.MetaphoneAlgorithm
/**
- * The metaphoneAlgorithm [[org.hashtree.stringmetric.cli.command.Command]]. Returns the phonetic representation of the
+ * The metaphoneAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the Metaphone algorithm.
*/
object metaphoneAlgorithm extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala
index 1d0b174..a915710 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/metaphoneMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.MetaphoneMetric
/**
- * The metaphoneMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to determine if they are
+ * The metaphoneMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Metaphone algorithm.
*/
object metaphoneMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithm.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala
index b4f4130..cf71bf5 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithm.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.NysiisAlgorithm
/**
- * The nysiisAlgorithm [[org.hashtree.stringmetric.cli.command.Command]]. Returns the phonetic representation of the
+ * The nysiisAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the NYSIIS algorithm.
*/
object nysiisAlgorithm extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala
index 741cea2..b9a1b3e 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/nysiisMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.NysiisMetric
/**
- * The nysiisMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to determine if they are
+ * The nysiisMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the NYSIIS algorithm.
*/
object nysiisMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithm.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala
index d935e71..5ac8eb6 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithm.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.RefinedSoundexAlgorithm
/**
- * The refinedSoundexAlgorithm [[org.hashtree.stringmetric.cli.command.Command]]. Returns the phonetic representation of the
+ * The refinedSoundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the refined Soundex algorithm.
*/
object refinedSoundexAlgorithm extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala
index d05e602..02740ce 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.RefinedSoundexMetric
/**
- * The refinedSoundexMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to determine if they are
+ * The refinedSoundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the refined Soundex algorithm.
*/
object refinedSoundexMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithm.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala
index ba64498..f879566 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithm.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.SoundexAlgorithm
/**
- * The soundexAlgorithm [[org.hashtree.stringmetric.cli.command.Command]]. Returns the phonetic representation of the
+ * The soundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the Soundex algorithm.
*/
object soundexAlgorithm extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala
index b49eadc..0cac5cc 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/soundexMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.StringFilterDelegate
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.phonetic.SoundexMetric
/**
- * The soundexMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to determine if they are
+ * The soundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Soundex algorithm.
*/
object soundexMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala
index a0f5dc5..1f2bdee 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.{ AsciiLetterCaseStringFilter, StringFilterDelegate }
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.similarity.DiceSorensenMetric
/**
- * The diceSorensenMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares the similarity of two strings
+ * The diceSorensenMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the similarity of two strings
* using the Dice coefficient / Sorensen similarity index.
*/
object diceSorensenMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/hammingMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala
index 29c6481..0813e5e 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/hammingMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.{ AsciiLetterCaseStringFilter, StringFilterDelegate }
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.similarity.HammingMetric
/**
- * The hammingMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares the number of characters that two equal
+ * The hammingMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two equal
* length strings are different from one another.
*/
object hammingMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala
index 156834c..3c5cc73 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.{ AsciiLetterCaseStringFilter, StringFilterDelegate }
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.similarity.JaroMetric
/**
- * The jaroMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to calculate the
+ * The jaroMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to calculate the
* Jaro distance.
*/
object jaroMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala
index 225311a..8cbcca8 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.{ AsciiLetterCaseStringFilter, StringFilterDelegate }
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.similarity.JaroWinklerMetric
/**
- * The jaroWinklerMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares two strings to calculate the
+ * The jaroWinklerMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to calculate the
* Jaro-Winkler distance.
*/
object jaroWinklerMetric extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/levenshteinMetric.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala
index cd259e4..aed6fcb 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/levenshteinMetric.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala
@@ -1,12 +1,11 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.{ AsciiLetterCaseStringFilter, StringFilterDelegate }
import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.cli.command._
import org.hashtree.stringmetric.similarity.LevenshteinMetric
/**
- * The levenshteinMetric [[org.hashtree.stringmetric.cli.command.Command]]. Compares the number of characters that two
+ * The levenshteinMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two
* strings are different from one another via insertion, deletion, and substitution.
*/
object levenshteinMetric extends Command {
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithmSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala
index 5de40e4..abf81eb 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneAlgorithmSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala
index dc04434..58ce5e0 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/metaphoneMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithmSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala
index 957a098..7a5d224 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisAlgorithmSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala
index 4c0beea..dfa6c22 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/nysiisMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithmSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala
index d8c9ce6..8db2b1f 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexAlgorithmSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala
index 480473a..029842f 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/refinedSoundexMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithmSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala
index 05ba8ae..cc9c28a 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexAlgorithmSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala
index 4fba289..e26b74f 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/soundexMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.phonetic
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala
index 33ea7dd..d9e2cb0 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/diceSorensenMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/hammingMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala
index f140505..3108090 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/hammingMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala
index 87544e8..c85a8c7 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala
index 02f9340..4755f37 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/jaroWinklerMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/levenshteinMetricSpec.scala b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala
index 77d7187..0a19550 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/command/levenshteinMetricSpec.scala
+++ b/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli.command
+package org.hashtree.stringmetric.cli.similarity
import org.hashtree.stringmetric.ScalaTest
import org.junit.runner.RunWith
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/package.scala b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala
index b0610ba..c0457a8 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/command/package.scala
+++ b/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala
@@ -1,6 +1,6 @@
package org.hashtree.stringmetric.cli
-/** Provides core command functionality. */
-package object command {
+/** Provides core similarity functionality. */
+package object similarity {
implicit val optionMap: OptionMap = OptionMapUtility.toOptionMap(Array("--unitTest=false"))
} \ No newline at end of file